@@ -13,6 +13,27 @@ class ExperimentAnalysis:
 
     """
 
+    RESULT_METRIC_SEPARATOR = ":"
+    TRANSFORM_TARGET_SEPARATOR = "/"
+
+    @classmethod
+    def split_target(cls, target):
+        transform = None
+        if cls.TRANSFORM_TARGET_SEPARATOR in target:
+            transform, target = target.split(cls.TRANSFORM_TARGET_SEPARATOR)
+        result, metric = target.split(cls.RESULT_METRIC_SEPARATOR)
+        return result, metric, transform
+
+    @classmethod
+    def get_data(cls, trial, target, aggregate=True):
+        result, metric, transform = cls.split_target(target)
+        if aggregate:
+            data = trial.get_stats(result, transform=transform)
+            return data[metric] if metric in data.columns else data.loc[metric]
+        else:
+            data = trial.get_data(result, transform=transform)
+            return [df[metric] for df in data]
+
     def __init__(self, logdir, name=None):
         self.logdir = logdir
         self.name = name
@@ -57,6 +78,8 @@ class ExperimentAnalysis:
                 self._trials[dirname] = trial
 
                 for key, value in trial.config.items():
+                    if isinstance(value, list):
+                        value = tuple(value)
                     self._params[key].add(value)
 
     def get(self, params_values):
